@@ -10,10 +10,10 @@ dpkg-checkbuilddeps -d 'python3-apt, apt-btrfs-snapshot, parsewiki, python3-feed
 
 # update demotions
 # echo "Running demotions"
-# (cd utils && ./demotions.py wily xenial > demoted.cfg)
+(cd utils && ./demotions.py xenial yakkety > demoted.cfg)
 # when this gets enabled, make sure to add symlink in DistUpgrade
 # echo "Running lts demotions"
-(cd utils && ./demotions.py trusty xenial > demoted.cfg.trusty)
+#(cd utils && ./demotions.py trusty xenial > demoted.cfg.trusty)
 
 # update apt_btrfs_snapshot.py copy, this needs an installed
 # apt-btrfs-snapshot on the build machine
@@ -46,6 +46,7 @@ xvfb-run nosetests3
 # test leftovers
 # echo "Cleaning up after tests"
 rm -f ./tests/data-sources-list-test/apt.log
+rm -f ./tests/data-sources-list-test/Ubuntu.mirrors
 
 # update version
 DEBVER=$(LC_ALL=C dpkg-parsechangelog |sed -n -e '/^Version:/s/^Version: //p' | sed s/.*://)
